"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PnpmNodeModulesCollector = void 0;
const nodeModulesCollector_1 = require("./nodeModulesCollector");
const path = require("path");
class PnpmNodeModulesCollector extends nodeModulesCollector_1.NodeModulesCollector {
    constructor(rootDir) {
        super(rootDir);
    }
    getCommand() {
        return process.platform === "win32" ? "pnpm.cmd" : "pnpm";
    }
    getArgs() {
        return ["list", "--prod", "--json", "--depth", "Infinity"];
    }
    extractRelevantData(npmTree) {
        const tree = super.extractRelevantData(npmTree);
        return {
            ...tree,
            optionalDependencies: this.extractInternal(npmTree.optionalDependencies),
        };
    }
    extractProductionDependencyTree(tree) {
        const p = path.normalize(this.resolvePath(tree.path));
        const packageJson = require(path.join(p, "package.json"));
        const prodDependencies = { ...(packageJson.dependencies || {}), ...(packageJson.optionalDependencies || {}) };
        const deps = { ...(tree.dependencies || {}), ...(tree.optionalDependencies || {}) };
        const dependencies = Object.entries(deps).reduce((acc, curr) => {
            const [packageName, dependency] = curr;
            if (!prodDependencies[packageName]) {
                return acc;
            }
            return {
                ...acc,
                [packageName]: this.extractProductionDependencyTree(dependency),
            };
        }, {});
        const { name, version, path: packagePath, workspaces } = tree;
        const depTree = {
            name,
            version,
            path: packagePath,
            workspaces,
            dependencies,
            implicitDependenciesInjected: false,
        };
        return depTree;
    }
    parseDependenciesTree(jsonBlob) {
        const dependencyTree = JSON.parse(jsonBlob);
        // pnpm returns an array of dependency trees
        return dependencyTree[0];
    }
}
exports.PnpmNodeModulesCollector = PnpmNodeModulesCollector;
//# sourceMappingURL=pnpmNodeModulesCollector.js.map